## README

Documentation for the *pqcprep* package is hosted [here](https://david-f-amorim.github.io/PQC_function_evaluation/pqcprep.html). 

The directory 'LEGACY' contains a few additional scripts beyond the core *pqcprep* functionality as well as legacy data. The directory 
'slides' contains various presentations on the project which could be helpful to read in conjunction with the documentation. 

### Imprint 

David Amorim, 2024. Email: [*2538354a@student.gla.ac.uk*](mailto:2538354a@student.gla.ac.uk) .


This project was funded by a Carnegie Vacation Scholarship and supervised by Prof Sarah Croke (University of Glasgow, School of Physics and Astronomy). 

